init_common_devices

Function init_common_devices 

pub fn init_common_devices(
    locked: &mut Locked<Unlocked>,
    kernel: &Kernel,
) -> Result<(), Errno>
Initializes common devices in Kernel.

Adding device nodes to devtmpfs requires the current running task. The Kernel constructor does not create an initial task, so this function should be triggered after a CurrentTask has been initialized.